==> Mk2_202a.zip: var/local/www/globaladvsettings.php <==
<?php session_start();
  header ("HTTP/1.1 200 OK");  
  include 'tcfunctions.php';  
?>
<html>
<head>
<?php htmlheadercontent(); ?>
</head>
<?php
  $conn = connect();
  bodyhtmlheader();
      
  if($_SESSION["logged_in"] == true){
    $a = @$_GET["a"];
    $sql = @$_POST["sql"];
  
    switch ($sql) {
      case "update":        
        sql_update();
        break;
    }             
    switch ($a) {
      default:
        editrec($recid);
        break;
    }
    $conn = null;
}?>
<?php bodyhtmlfooter(); ?>
</html>

<?php function showroweditor($row, $iseditmode)
  {
  global $conn;
?>
<!--Tab1-->
<div id="Tab_advprocform">
  <div class="dhtmlgoodies_aTab" id="Tab_advprocform_1">
    <input type="hidden" name="xid" value="<?php echo $row["id"] ?>">
    <input type="hidden" name="pc" value="<?php echo $row["pc"] ?>">            
    <table class="tbl" border="0" cellspacing="1" cellpadding="5">
        <tr>
            <td colspan="2" class="hr">Assign hours to the following time categories</td>        
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Extra Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="extracat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["extracat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Normal Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="normalcat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["normalcat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Overtime Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="overtimecat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["overtimecat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>        
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Saturday Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="satcat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["satcat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>        
        </tr>            
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Sun Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="suncat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["suncat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>                
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Holiday Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="holidaycat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["holidaycat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Variance Category")."&nbsp;" ?></td>
                    <td class="dr">
                <select name="variancecat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["variancecat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>
    </table>
  </div>
  <!--Tab2-->  
  <div class="dhtmlgoodies_aTab" id="Tab_advprocform_1">  
    <table class="tbl" border="0" cellspacing="1" cellpadding="5">
        <tr>
            <td colspan="2" class="hr">Set threshold before hours are allocated</td>        
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Extra Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold1" value="<?php echo htmlspecialchars(formatsec2str($row["threshold1"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Normal Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold2" value="<?php echo htmlspecialchars(formatsec2str($row["threshold2"],$_SESSION["hrsindec"])) ?>"></td>            
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Overtime Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold3" value="<?php echo htmlspecialchars(formatsec2str($row["threshold3"],$_SESSION["hrsindec"])) ?>"></td>            
        </tr>        
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Saturday Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold4" value="<?php echo htmlspecialchars(formatsec2str($row["threshold4"],$_SESSION["hrsindec"])) ?>"></td>
            
        </tr>            
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Sun Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold5" value="<?php echo htmlspecialchars(formatsec2str($row["threshold5"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>                
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Holiday Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold6" value="<?php echo htmlspecialchars(formatsec2str($row["threshold6"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Paid Leave")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold7" value="<?php echo htmlspecialchars(formatsec2str($row["threshold7"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>                        
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Sick Leave")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold8" value="<?php echo htmlspecialchars(formatsec2str($row["threshold8"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>                                
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Variance Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold9" value="<?php echo htmlspecialchars(formatsec2str($row["threshold9"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>
    </table>
  </div>  
</div>
<script type="text/javascript">
    initTabs('Tab_advprocform',Array('General','Time Category Thresholds'),0,"100%","");
</script>    
<?php } ?>
<?php function editrec($recid)
{
  $res = sql_select();
  $count = sql_getrecordcount();
  sqlite_seek_ex($res, $recid);
  $row = sqlite_fetch_array_ex($res);
?>

<?php formhtmlheader('Update Advanced Global Processor Settings') ?>
    <form enctype="multipart/form-data" action="globaladvsettings.php" method="post">
        <input type="hidden" name="sql" value="update">        
        <?php showroweditor($row, true); ?>
        <br>
        <table align="center">
            <tr>
                <td>                    
                    <input type="submit" name="action" value="Save" class="normalbutton">                                        
                    <input type="button" value="Cancel" onclick="window.location='globaladvsettings.php'" class="normalbutton">                                        
                </td>
            </tr>
        </table>                                  
    </form>
<?php formhtmlfooter() ?>
<?php } ?>

<?php function sql_select()
{
  global $conn;
  $sql = "SELECT id, autoproc, cat1, cat2, cat3, cat4, cat5, cat6, cat7, cat8, cat9,
         balancing, rounding,
         threshold1, threshold2, threshold3, threshold4, threshold5, threshold6, threshold7, threshold8, threshold9, 
         extracat, normalcat, overtimecat, satcat, suncat, holidaycat, variancecat,
         sunday, monday, tuesday, wednesday, thursday, friday, saturday,
         lastdate, autoendday, runningtotals , pc
         FROM gloproc";
  $res = $conn->query($sql) or die('<br/>Error in qeury string:<br/>' .$sql .'<br/>');    
  return $res;  
}

function sql_getrecordcount()
{
  global $conn;  
  $sql = "SELECT COUNT(*) FROM gloproc";
  $res = $conn->query($sql) or die('<br/>Error in qeury string:<br/>' .$sql .'<br/>');
  $row = sqlite_fetch_array_ex($res);
  reset($row);
  return current($row);
}

function sql_update()
{
  global $conn;
  global $_POST;
  if (!isset($_POST['autoproc'])){$autoproc = "0";} else {$autoproc = "1";}
  if (!isset($_POST['balancing'])){$balancing = "0";} else {$balancing = "1";}
  $sql = "update gloproc set extracat=" .sqlvalue(@$_POST["extracat"], true, false).",normalcat=" .sqlvalue(@$_POST["normalcat"], true, false)
         .",overtimecat=" .sqlvalue(@$_POST["overtimecat"], true, false).",satcat=" .sqlvalue(@$_POST["satcat"], true, false)
         .",suncat=" .sqlvalue(@$_POST["suncat"], true, false).",holidaycat=" .sqlvalue(@$_POST["holidaycat"], true, false)
         .",variancecat=" .sqlvalue(@$_POST["variancecat"], true, false).", pc=" .setpcstatus(@$_POST["pc"])
         .",threshold1=" .formatstr2sec(@$_POST["threshold1"], 0, 0).", threshold2=" .formatstr2sec(@$_POST["threshold2"], 0, 0).", threshold3=" .formatstr2sec(@$_POST["threshold3"], 0, 0) 
         .",threshold4=" .formatstr2sec(@$_POST["threshold4"], 0, 0).", threshold5=" .formatstr2sec(@$_POST["threshold5"], 0, 0).", threshold6=" .formatstr2sec(@$_POST["threshold6"], 0, 0) 
         .",threshold7=" .formatstr2sec(@$_POST["threshold7"], 0, 0).", threshold8=" .formatstr2sec(@$_POST["threshold8"], 0, 0).", threshold9=" .formatstr2sec(@$_POST["threshold9"], 0, 0) 
         ." where " .primarykeycondition();  
  dbaction($conn,$sql,false);
  reloadcache(1);
  loadprocdefaults();
}

function primarykeycondition()
{
  global $_POST;
  $pk = "";
  $pk .= "(id";
  if (@$_POST["xid"] == "") {
    $pk .= " IS NULL";
  }else{
  $pk .= " = " .sqlvalue(@$_POST["xid"], false, true);
  };
  $pk .= ")";
  return $pk;
}
?>

==> Mk2_204b.zip: var/local/www/globaladvsettings.php <==
<?php session_start();
  header ("HTTP/1.1 200 OK");  
  include 'tcfunctions.php';  
  setlanguage();
?>
<html>
<head>
<?php htmlheadercontent(); ?>
</head>
<?php
  $conn = connect();
  bodyhtmlheader();
      
  if($_SESSION["logged_in"] == true){
    $a = @$_GET["a"];
    $sql = @$_POST["sql"];
  
    switch ($sql) {
      case "update":        
        sql_update();
        break;
    }             
    switch ($a) {
      default:
        editrec($recid);
        break;
    }
    $conn = null;
}?>
<?php bodyhtmlfooter(); ?>
</html>

<?php function showroweditor($row, $iseditmode)
  {
  global $conn;
?>
<!--Tab1-->
<div id="Tab_advprocform">
  <div class="dhtmlgoodies_aTab" id="Tab_advprocform_1">
    <input type="hidden" name="xid" value="<?php echo $row["id"] ?>">
    <input type="hidden" name="pc" value="<?php echo $row["pc"] ?>">            
    <table class="tbl" border="0" cellspacing="1" cellpadding="5">
        <tr>
            <td colspan="2" class="hr">Assign hours to the following time categories</td>        
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Extra Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="extracat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["extracat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Normal Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="normalcat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["normalcat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Overtime Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="overtimecat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["overtimecat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>        
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Saturday Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="satcat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["satcat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>        
        </tr>            
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Sun Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="suncat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["suncat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>                
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Holiday Category")."&nbsp;" ?></td>
            <td class="dr">
                <select name="holidaycat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["holidaycat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Variance Category")."&nbsp;" ?></td>
                    <td class="dr">
                <select name="variancecat">
                  <?php
                    for ($i = 1; $i <= 9; $i++){
                        $val = $i;
                        $caption = $_SESSION["cat" .$i];
                        if ($row["variancecat"] == $val) {$selstr = " selected=\"selected\" ";} else {$selstr = ""; }
                        ?>
                        <option value="<?php echo $val ?>"<?php echo $selstr ?>><?php echo $caption ?></option>
                        <?php
                    }
                    ?>
                </select>
            </td>
        </tr>
    </table>
  </div>
  <!--Tab2-->  
  <div class="dhtmlgoodies_aTab" id="Tab_advprocform_1">  
    <table class="tbl" border="0" cellspacing="1" cellpadding="5">
        <tr>
            <td colspan="2" class="hr">Set threshold before hours are allocated</td>        
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Extra Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold1" value="<?php echo htmlspecialchars(formatsec2str($row["threshold1"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Normal Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold2" value="<?php echo htmlspecialchars(formatsec2str($row["threshold2"],$_SESSION["hrsindec"])) ?>"></td>            
        </tr>    
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Overtime Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold3" value="<?php echo htmlspecialchars(formatsec2str($row["threshold3"],$_SESSION["hrsindec"])) ?>"></td>            
        </tr>        
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Saturday Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold4" value="<?php echo htmlspecialchars(formatsec2str($row["threshold4"],$_SESSION["hrsindec"])) ?>"></td>
            
        </tr>            
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Sun Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold5" value="<?php echo htmlspecialchars(formatsec2str($row["threshold5"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>                
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Holiday Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold6" value="<?php echo htmlspecialchars(formatsec2str($row["threshold6"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Paid Leave")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold7" value="<?php echo htmlspecialchars(formatsec2str($row["threshold7"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>                        
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Sick Leave")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold8" value="<?php echo htmlspecialchars(formatsec2str($row["threshold8"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>                                
        <tr>
            <td class="hr"><?php echo htmlspecialchars("Variance Category")."&nbsp;" ?></td>
            <td class="dr"><input class="il1" <?php echo $inputmode ?> type="text" name="threshold9" value="<?php echo htmlspecialchars(formatsec2str($row["threshold9"],$_SESSION["hrsindec"])) ?>"></td>
        </tr>
    </table>
  </div>  
</div>
<script type="text/javascript">
    initTabs('Tab_advprocform',Array('General','Time Category Thresholds'),0,"100%","");
</script>    
<?php } ?>
<?php function editrec($recid)
{
  $res = sql_select();
  $count = sql_getrecordcount();
  sqlite_seek_ex($res, $recid);
  $row = sqlite_fetch_array_ex($res);
?>

<?php formhtmlheader('Update Advanced Global Processor Settings') ?>
    <form enctype="multipart/form-data" action="globaladvsettings.php" method="post">
        <input type="hidden" name="sql" value="update">        
        <?php showroweditor($row, true); ?>
        <br>
        <table align="center">
            <tr>
                <td>                    
                    <input type="submit" name="action" value="<?php echo $_SESSION["Save"] ?>" class="normalbutton">                                        
                    <input type="button" value="<?php echo $_SESSION["Cancel"] ?>" onclick="window.location='globaladvsettings.php'" class="normalbutton">                                        
                </td>
            </tr>
        </table>                                  
    </form>
<?php formhtmlfooter() ?>
<?php } ?>

<?php function sql_select()
{
  global $conn;
  $sql = "SELECT id, autoproc, cat1, cat2, cat3, cat4, cat5, cat6, cat7, cat8, cat9,
         balancing, rounding,
         threshold1, threshold2, threshold3, threshold4, threshold5, threshold6, threshold7, threshold8, threshold9, 
         extracat, normalcat, overtimecat, satcat, suncat, holidaycat, variancecat,
         sunday, monday, tuesday, wednesday, thursday, friday, saturday,
         lastdate, autoendday, runningtotals , pc
         FROM gloproc";
  $res = $conn->query($sql) or die('<br/>Error in qeury string:<br/>' .$sql .'<br/>');    
  return $res;  
}

function sql_getrecordcount()
{
  global $conn;  
  $sql = "SELECT COUNT(*) FROM gloproc";
  $res = $conn->query($sql) or die('<br/>Error in qeury string:<br/>' .$sql .'<br/>');
  $row = sqlite_fetch_array_ex($res);
  reset($row);
  return current($row);
}

function sql_update()
{
  global $conn;
  global $_POST;
  if (!isset($_POST['autoproc'])){$autoproc = "0";} else {$autoproc = "1";}
  if (!isset($_POST['balancing'])){$balancing = "0";} else {$balancing = "1";}
  $sql = "update gloproc set extracat=" .sqlvalue(@$_POST["extracat"], true, false).",normalcat=" .sqlvalue(@$_POST["normalcat"], true, false)
         .",overtimecat=" .sqlvalue(@$_POST["overtimecat"], true, false).",satcat=" .sqlvalue(@$_POST["satcat"], true, false)
         .",suncat=" .sqlvalue(@$_POST["suncat"], true, false).",holidaycat=" .sqlvalue(@$_POST["holidaycat"], true, false)
         .",variancecat=" .sqlvalue(@$_POST["variancecat"], true, false).", pc=" .setpcstatus(@$_POST["pc"])
         .",threshold1=" .formatstr2sec(@$_POST["threshold1"], $_SESSION["hrsindec"], 0).", threshold2=" .formatstr2sec(@$_POST["threshold2"], $_SESSION["hrsindec"], 0).", threshold3=" .formatstr2sec(@$_POST["threshold3"], $_SESSION["hrsindec"], 0) 
         .",threshold4=" .formatstr2sec(@$_POST["threshold4"], $_SESSION["hrsindec"], 0).", threshold5=" .formatstr2sec(@$_POST["threshold5"], $_SESSION["hrsindec"], 0).", threshold6=" .formatstr2sec(@$_POST["threshold6"], $_SESSION["hrsindec"], 0) 
         .",threshold7=" .formatstr2sec(@$_POST["threshold7"], $_SESSION["hrsindec"], 0).", threshold8=" .formatstr2sec(@$_POST["threshold8"], $_SESSION["hrsindec"], 0).", threshold9=" .formatstr2sec(@$_POST["threshold9"], $_SESSION["hrsindec"], 0) 
         ." where " .primarykeycondition();  
  dbaction($conn,$sql,false);
  reloadcache(1);
  loadprocdefaults();
}

function primarykeycondition()
{
  global $_POST;
  $pk = "";
  $pk .= "(id";
  if (@$_POST["xid"] == "") {
    $pk .= " IS NULL";
  }else{
  $pk .= " = " .sqlvalue(@$_POST["xid"], false, true);
  };
  $pk .= ")";
  return $pk;
}
?>
